# sesg-package

> SeSG (Search String Generator) python package repository.

[![Documentation Status](https://readthedocs.org/projects/sesg-package/badge/?version=latest)](https://sesg-package.readthedocs.io/en/latest/?badge=latest)

SeSG is a tool developed to help Systematic Literature Review researchers, specifically at the step of building a search string.

## Installation

You can install with `pip`, `poetry`, or any other package manager:

```bash
poetry add sesg
```
